# maysics
本库是用于科学计算和快速建模

maysics主要包括九个模块：<br/>
1、algorithm 封装了几种算法，用于简易模拟；<br/>
2、calculus 封装了常见的算符算子，辅助数学运算；<br/>
3、constant 储存了部分常数；<br/>
4、models 封装了几种常用的数学物理定律、方程、模型以便快速构建数理模型；<br/>
5、model_selection 用于评估和选择模型；<br/>
6、preprocess 用于数据预处理；<br/>
7、stats 用于统计分析；<br/>
8、transformation 封装了常用的坐标转换及其他数学变换；<br/>
9、utils 是额外工具箱。<br/>


This package is used for scientific calculating and fast modeling

maysics includes nine modules:<br/>
1. "algorithm" packages several algorithms for simple simulation;<br/>
2. "calculus" packaes common operatoes;<br/>
3. "constant" stores common constants;<br/>
4. "models" packages several coommon laws and equations of physics and models for fast modeling;<br/>
5. "model_selection" used for estimating and selecting models;<br/>
6. "preprocess" is used for data preproccessing;<br/>
7. "stats" is uesd for statistical analysis;<br/>
8. "transformation" packages common coordinate transformations and other mathematical transformations;<br/>
9. "utils" is extra Utils.